      SUBROUTINE LGRNGN (AU, NA, AN)
C     ******************************************************************
C     FORTRAN SUBROUTINE FOR LAGRANGIAN NORMALIZATION FACTORS
C     ******************************************************************
C     AU = COORDINATE ARGUMENTS  (N-ARRAY)
C     NA = NUMBER OF ARGUMENTS   (N)
C     AN = NORMALIZATION FACTORS (N-ARRAY)
C
      DIMENSION AU(1), AN(1)
  001 DO 003 K=1,NA
      TM=1.0
      DO 002 M=1,NA
      IF(M.EQ.K)GO TO 002
      DM=AU(K)-AU(M)
      TM=DM*TM
  002 CONTINUE
      AN(K)=TM
  003 CONTINUE
      RETURN
      END
